==> jc-1.4.0.tar.gz: javax/security/cert/CertificateEncodingException.h <==
// public class javax.security.cert.CertificateEncodingException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3a819268ecfacd6e javax_security_cert_CertificateEncodingException
// @dep_class 8a16a5ccc9026182 javax_security_cert_CertificateException

// header file dependencies
// @dep_header javax_security_cert_CertificateException

#include "javax/security/cert/CertificateException.h"

#ifndef _JC_javax_security_cert_CertificateEncodingException_H_
#define _JC_javax_security_cert_CertificateEncodingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_cert_CertificateEncodingException$sub_refs	_jc_javax_security_cert_CertificateEncodingException$sub_refs;
typedef struct _jc_javax_security_cert_CertificateEncodingException$sub_nonrefs	_jc_javax_security_cert_CertificateEncodingException$sub_nonrefs;
typedef struct _jc_javax_security_cert_CertificateEncodingException$refs	_jc_javax_security_cert_CertificateEncodingException$refs;
typedef struct _jc_javax_security_cert_CertificateEncodingException$nonrefs	_jc_javax_security_cert_CertificateEncodingException$nonrefs;
typedef struct _jc_javax_security_cert_CertificateEncodingException$object	_jc_javax_security_cert_CertificateEncodingException$object;

typedef const struct _jc_javax_security_cert_CertificateEncodingException$vmethods	_jc_javax_security_cert_CertificateEncodingException$vmethods;
typedef const struct _jc_javax_security_cert_CertificateEncodingException$vtable	_jc_javax_security_cert_CertificateEncodingException$vtable;
typedef const struct _jc_javax_security_cert_CertificateEncodingException$vtype	_jc_javax_security_cert_CertificateEncodingException$vtype;

// Constructors
extern void _jc_javax_security_cert_CertificateEncodingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_cert_CertificateEncodingException$object *);
extern void _jc_javax_security_cert_CertificateEncodingException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_cert_CertificateEncodingException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_security_cert_CertificateEncodingException$vmethods {
};

// Vtable
struct _jc_javax_security_cert_CertificateEncodingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_security_cert_CertificateException$vmethods	javax_security_cert_CertificateException;
	_jc_javax_security_cert_CertificateEncodingException$vmethods	javax_security_cert_CertificateEncodingException;
};

// Vtype
struct _jc_javax_security_cert_CertificateEncodingException$vtype {
	_jc_type			type;
	_jc_javax_security_cert_CertificateEncodingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_cert_CertificateEncodingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_cert_CertificateEncodingException$refs {
    _jc_javax_security_cert_CertificateEncodingException$sub_refs	javax_security_cert_CertificateEncodingException;
    _jc_javax_security_cert_CertificateException$sub_refs	javax_security_cert_CertificateException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_cert_CertificateEncodingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_cert_CertificateEncodingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_security_cert_CertificateException$sub_nonrefs	javax_security_cert_CertificateException;
    _jc_javax_security_cert_CertificateEncodingException$sub_nonrefs	javax_security_cert_CertificateEncodingException;
};

// Object instance structure
struct _jc_javax_security_cert_CertificateEncodingException$object {
	_jc_javax_security_cert_CertificateEncodingException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_cert_CertificateEncodingException$vtype	*vtype;
	_jc_javax_security_cert_CertificateEncodingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_cert_CertificateEncodingException$vtype _jc_javax_security_cert_CertificateEncodingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_cert_CertificateEncodingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_cert_CertificateEncodingException$class_object;

#endif	/* _JC_javax_security_cert_CertificateEncodingException_H_ */

==> jc-1.4.6.tar.gz: javax/security/cert/CertificateEncodingException.h <==
// public class javax.security.cert.CertificateEncodingException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3a819268ecfacd6e javax_security_cert_CertificateEncodingException
// @dep_class 8a16a5ccc9026182 javax_security_cert_CertificateException

// header file dependencies
// @dep_header javax_security_cert_CertificateException

#include "javax/security/cert/CertificateException.h"

#ifndef _JC_javax_security_cert_CertificateEncodingException_H_
#define _JC_javax_security_cert_CertificateEncodingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_cert_CertificateEncodingException$sub_refs	_jc_javax_security_cert_CertificateEncodingException$sub_refs;
typedef struct _jc_javax_security_cert_CertificateEncodingException$sub_nonrefs	_jc_javax_security_cert_CertificateEncodingException$sub_nonrefs;
typedef struct _jc_javax_security_cert_CertificateEncodingException$refs	_jc_javax_security_cert_CertificateEncodingException$refs;
typedef struct _jc_javax_security_cert_CertificateEncodingException$nonrefs	_jc_javax_security_cert_CertificateEncodingException$nonrefs;
typedef struct _jc_javax_security_cert_CertificateEncodingException$object	_jc_javax_security_cert_CertificateEncodingException$object;

typedef const struct _jc_javax_security_cert_CertificateEncodingException$vmethods	_jc_javax_security_cert_CertificateEncodingException$vmethods;
typedef const struct _jc_javax_security_cert_CertificateEncodingException$vtable	_jc_javax_security_cert_CertificateEncodingException$vtable;
typedef const struct _jc_javax_security_cert_CertificateEncodingException$vtype	_jc_javax_security_cert_CertificateEncodingException$vtype;

// Constructors
extern void _jc_javax_security_cert_CertificateEncodingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_cert_CertificateEncodingException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_cert_CertificateEncodingException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_cert_CertificateEncodingException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_cert_CertificateEncodingException$vmethods {
};

// Vtable
struct _jc_javax_security_cert_CertificateEncodingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_security_cert_CertificateException$vmethods	javax_security_cert_CertificateException;
	_jc_javax_security_cert_CertificateEncodingException$vmethods	javax_security_cert_CertificateEncodingException;
};

// Vtype
struct _jc_javax_security_cert_CertificateEncodingException$vtype {
	_jc_type			type;
	_jc_javax_security_cert_CertificateEncodingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_cert_CertificateEncodingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_cert_CertificateEncodingException$refs {
    _jc_javax_security_cert_CertificateEncodingException$sub_refs	javax_security_cert_CertificateEncodingException;
    _jc_javax_security_cert_CertificateException$sub_refs	javax_security_cert_CertificateException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_cert_CertificateEncodingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_cert_CertificateEncodingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_security_cert_CertificateException$sub_nonrefs	javax_security_cert_CertificateException;
    _jc_javax_security_cert_CertificateEncodingException$sub_nonrefs	javax_security_cert_CertificateEncodingException;
};

// Object instance structure
struct _jc_javax_security_cert_CertificateEncodingException$object {
	_jc_javax_security_cert_CertificateEncodingException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_cert_CertificateEncodingException$vtype	*vtype;
	_jc_javax_security_cert_CertificateEncodingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_cert_CertificateEncodingException$vtype _jc_javax_security_cert_CertificateEncodingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_cert_CertificateEncodingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_cert_CertificateEncodingException$class_object;

#endif	/* _JC_javax_security_cert_CertificateEncodingException_H_ */
